@@ -2,7 +2,7 @@ package Perl6::Doc;
 use 5.000;
 use File::Spec;
 
-$Perl6::Doc::VERSION = '0.34.3';
+$Perl6::Doc::VERSION = '0.35.1';
 
 sub new {
     my $class = shift;
@@ -197,7 +197,7 @@ Perl6::Doc - all useful Perl 6 Docs in your command line
 =head1 VERSION
 
 This document describes version 0.35 of Perl6::Doc, released
-January 23, 2008.
+February 3, 2008.
 
 =head1 SYNOPSIS
 
@@ -325,13 +325,15 @@ Perl 6, like I<Programming Perl> is for Perl 5.
 Note that while these documents still being subjected to the rigours 
 of cross-examination through implementation.
 
-=head2 Perl 6 Docs (Overview and FAQ)
+=head2 Perl 6 User Documentation
+
+=head3 Overview and FAQ
 
 These are shorter summaries about a smaller specific topic. They are
 written mostly by the crazy Pugs people and replacing some of the
 outdated Synopses that are still marked as [Draft].
 
-=head2 Tutorial (building up)
+=head3 Tutorial (building up)
 
 This is an community driven effort to translate the Perl 5 manpages
 into the shiny Perl 6 world. There are still are half way through the
@@ -355,6 +357,43 @@ Perl6::Doc provides a class method to get the raw text of a document:
 
 =head1 AUTHORS
 
+=head2 COPYRIGHT
+
+This Copyright applies only to the C<Perl6::Doc> Perl software
+distribution, not the documents bundled within.
+
+Copyright (c) 2007. Ingy dt Net, Herbert Breunung. All rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
+See http://www.perl.com/perl/misc/Artistic.html
+
+=cut
+
+=head2 PACKAGING
+
+Collection of docs is currently done by: 
+
+Herbert Breunung <lichtkind@cpan.org>
+
+=head2 SOURCES
+
+A couple of paragraphs from I<Perl 6 Essentials> were used for the
+overview. Most of the Bible docs (Apocalypses, Exegeses, Synopses)
+are from the official Perl development site. 
+
+L<http://dev.perl.org/perl6/>
+
+All draft Synopses, Overview, FAQ and Tutorial pages were taken out 
+of the Pugs SVN repository.
+
+L<http://svn.pugscode.org/pugs/docs/Perl6/>
+
+Articles are from:
+
+L<http://perl.com/pub/q/Article_Archive#Perl%206>
+
 =head2 SCRIBES
 
 These are the authors of the included docs, named in the order their work 
@@ -392,41 +431,4 @@ was added :
 
 * Pawel Murias <13pawel@gazeta.pl>
 
-* Herbert Breunung <lichtkind@cpan.org>
-
-=head2 SOURCES
-
-A couple of paragraphs from I<Perl 6 Essentials> were used for the
-overview. Most of the Bible docs (Apocalypses, Exegeses, Synopses)
-are from the official Perl development site. 
-
-L<http://dev.perl.org/perl6/>
-
-All draft Synopses, Overview, FAQ and Tutorial pages were taken out 
-of the Pugs SVN repository.
-
-L<http://svn.pugscode.org/pugs/docs/Perl6/>
-
-Articles are from:
-
-L<http://perl.com/pub/q/Article_Archive#Perl%206>
-
-=head2 PACKAGING
-
-Collection of docs is currently done by: 
-
-Herbert Breunung <lichtkind@cpan.org>
-
-=head2 COPYRIGHT
-
-This Copyright applies only to the C<Perl6::Doc> Perl software
-distribution, not the documents bundled within.
-
-Copyright (c) 2007. Ingy dt Net, Herbert Breunung. All rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See http://www.perl.com/perl/misc/Artistic.html
-
-=cut
+* Herbert Breunung <lichtkind@cpan.org>
\ No newline at end of file
